@@ -250,7 +250,7 @@ public:
     /**
      * Constructs an action.
      */
-    explicit KAction(QObject *parent);
+    KDELIBS4SUPPORT_DEPRECATED explicit KAction(QObject *parent);
 
     /**
      * Constructs an action with the specified parent and visible text.
@@ -276,7 +276,7 @@ public:
     /**
      * Standard destructor
      */
-    virtual ~KAction();
+    ~KAction() override;
 
     /**
      * Sets the help text for the action.
